//	AppSettingsExample.cpp - Example of how to implement the unimplemented
//							 AppSettings bits.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "AppSettings.h"
#include "Application.h"
#include "DebugHeaders.h"

#include "GamePlayState.h"
#include "TitleScreen.h"

#include "MinimalSounder.h"

#include "drawing/GLImmediateDrawer.h"
#include "drawing/GLESDrawer.h"
#include "GlobalData.h"

#include <sstream>

using std::wstringstream;
using std::wstring;

//------------------------------------------------------------------------------
wstring AppSettings::applicationName = L"Minimal 2 Player Game";
wstring AppSettings::applicationVersion = L"1.00";

//------------------------------------------------------------------------------
void AppSettings::initialise(CmdLineParams& cmdLine,
							 Application *app,
							 KeyManager& keyManager,
							 wstring& helpText)
{
	//Register your interest in any command line arguments.

	//Setup the dimensions of the drawing area.
	setDrawingDimensions(1280, 720, AlterRatio);

	//Register all possible GameStates.
	app->registerGameState(L"TitleScreen", &TitleScreen::creator, true);
	app->registerGameState(L"GamePlayState", &GamePlayState::creator);

	//Setup some default key mappings.
	// - Player 1 movement.
	keyManager.addMapping(L"P1Up", L"w", true);
	keyManager.addMapping(L"P1Left", L"a", true);
	keyManager.addMapping(L"P1Right", L"d", true);
	keyManager.addMapping(L"P1Down", L"s", true);
	keyManager.addMapping(L"P1Fire", L"Space", true);

	keyManager.addMapping(L"P1Up", L"Joy0Up", true);
	keyManager.addMapping(L"P1Left", L"Joy0Left", true);
	keyManager.addMapping(L"P1Right", L"Joy0Right", true);
	keyManager.addMapping(L"P1Down", L"Joy0Down", true);
#ifdef OSX
	keyManager.addMapping(L"P1Fire", L"Joy0Button11", true);
#else
	keyManager.addMapping(L"P1Fire", L"Joy0Button0", true);
#endif
	keyManager.addMapping(L"P1FireUp", L"Joy0Up2", true);
	keyManager.addMapping(L"P1FireLeft", L"Joy0Left2", true);
	keyManager.addMapping(L"P1FireRight", L"Joy0Right2", true);
	keyManager.addMapping(L"P1FireDown", L"Joy0Down2", true);

	// - Player 2 movement.
	keyManager.addMapping(L"P2Up", L"CursorUp", true);
	keyManager.addMapping(L"P2Left", L"CursorLeft", true);
	keyManager.addMapping(L"P2Right", L"CursorRight", true);
	keyManager.addMapping(L"P2Down", L"CursorDown", true);
	keyManager.addMapping(L"P2Fire", L"Return", true);

	keyManager.addMapping(L"P2Up", L"Joy1Up", true);
	keyManager.addMapping(L"P2Left", L"Joy1Left", true);
	keyManager.addMapping(L"P2Right", L"Joy1Right", true);
	keyManager.addMapping(L"P2Down", L"Joy1Down", true);
#ifdef OSX
	keyManager.addMapping(L"P2Fire", L"Joy1Button11", true);
#else
	keyManager.addMapping(L"P2Fire", L"Joy1Button0", true);
#endif
	keyManager.addMapping(L"P2FireUp", L"Joy1Up2", true);
	keyManager.addMapping(L"P2FireLeft", L"Joy1Left2", true);
	keyManager.addMapping(L"P2FireRight", L"Joy1Right2", true);
	keyManager.addMapping(L"P2FireDown", L"Joy1Down2", true);

	// - General.
	keyManager.addMapping(L"Escape", L"Escape", true);

#ifdef OSX
	keyManager.addMapping(L"Escape", L"Joy0Button5", true);
	keyManager.addMapping(L"Escape", L"Joy1Button5", true);
#else
	keyManager.addMapping(L"Escape", L"Joy0Button6", true);
	keyManager.addMapping(L"Escape", L"Joy1Button6", true);
#endif
	keyManager.addMapping(L"Restart", L"r", true);
#ifdef OSX
	keyManager.addMapping(L"Restart", L"Joy0Button4", true);
	keyManager.addMapping(L"Restart", L"Joy1Button4", true);
#else
	keyManager.addMapping(L"Restart", L"Joy0Button7", true);
	keyManager.addMapping(L"Restart", L"Joy1Button7", true);
#endif

	//Fill out helpText.

	//Set the LoadingScreen colours.
}

//------------------------------------------------------------------------------
DrawerPtr AppSettings::getDrawer(const std::wstring& drawerType)
{
	if(drawerType == L"GLImmediateDrawer")
		return DrawerPtr(new GLImmediateDrawer());
	else
	{
		if(GLESDrawer::isSupported())
			return DrawerPtr(new GLESDrawer());
		else
		{
			DebugStatement(L"GLESDrawer not supported. Falling back to GLImmediateDrawer");
			return DrawerPtr(new GLImmediateDrawer());
		}
	}
}

//------------------------------------------------------------------------------
SounderPtr AppSettings::getSounder()
{
	return SounderPtr(new MinimalSounder());
}

//------------------------------------------------------------------------------
GlobalDataPtr AppSettings::getGlobalData()
{
	return GlobalDataPtr(new GlobalData());
}

