//	Ball.cpp - The ball.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "ParticleGenerator.h"
#include "MinimalSounder.h"
#include "drawing/Drawer.h"
#include "GamePlayState.h"
#include "Random.h"
#include "Ball.h"

//------------------------------------------------------------------------------
Ball::Ball(const TwoFloats& pos,
		   bool dir,
		   shared_ptr<MinimalSounder>& sound,
		   ParticleGenerator& party,
		   GamePlayState& state):
position(pos),
name(L"Ball"),
speed(5.0f),
sounder(sound),
particles(party),
gameState(state)
{
	if(dir)
		direction.x = 1.0f;
	else
		direction.x = -1.0f;

	direction.y = Random::getGlobal().getRandomFloat() - 0.5f;
	direction = direction.normal();
}

//------------------------------------------------------------------------------
Ball::~Ball()
{

}

//------------------------------------------------------------------------------
void Ball::update(const TwoFloats& drawSize)
{
	position += direction * speed;

	speed += 0.001f;
	if(speed > 32.0f)
		speed = 32.0f;
}

//------------------------------------------------------------------------------
void Ball::draw(shared_ptr<Drawer>& d)
{
	d->drawImage(L"Blob", position-(16.0f*1.0f), 1.0f);
}

//------------------------------------------------------------------------------
void Ball::kick()
{
	owner = 0.0f;
	speed = 12.0f;
}

//------------------------------------------------------------------------------
void Ball::resetSpeed(bool dir)
{
	speed = 3.0f;

	if(dir)
		direction.x = 1.0f;
	else
		direction.x = -1.0f;

	direction.y = Random::getGlobal().getRandomFloat() - 0.5f;
	direction = direction.normal();
}

//------------------------------------------------------------------------------
void Ball::setPosition(const TwoFloats& pos)
{
	position = pos;
}

//------------------------------------------------------------------------------
void Ball::setOwner(const ThreeFloats& col)
{
	owner = col;
}

//------------------------------------------------------------------------------
void Ball::setDirection(const TwoFloats& dir)
{
	direction = dir;
	speed += 0.75f;
	sounder->triggerCollision(Random::getGlobal().getRandomInt(8));
	particles.trigger(position, 1.0f);
	gameState.shakeScreen();
}

//------------------------------------------------------------------------------
void Ball::collide(const shared_ptr<Collidable>& other)
{

}
