//	Bullet.cpp - Bullet for players to shoot.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "Bullet.h"

//------------------------------------------------------------------------------
Bullet::Bullet(const TwoFloats& pos,
			   const ThreeFloats& col,
			   const TwoFloats& dir):
position(pos),
direction(dir),
name(L"Bullet"),
colour(col),
dead(false)
{
	
}

//------------------------------------------------------------------------------
Bullet::~Bullet()
{

}

//------------------------------------------------------------------------------
void Bullet::update(const TwoFloats& drawSize)
{
	const float speed = 10.0f;

	position += direction * speed;
}

//------------------------------------------------------------------------------
void Bullet::draw(shared_ptr<Drawer>& d)
{
	TwoFloats tempDir(direction.x, -direction.y);

	d->drawRotImage(L"Bullet",
					position-8.0f,
					tempDir.getAngle(),
					8.0f,
					1.0f,
					colour);
}

//------------------------------------------------------------------------------
void Bullet::setDead()
{
	dead = true;
}

//------------------------------------------------------------------------------
void Bullet::setPosition(const TwoFloats& pos)
{
	position = pos;
}

//------------------------------------------------------------------------------
void Bullet::setColour(const ThreeFloats& col)
{
	colour = col;
}
