//	CaptureTheFlagPlayer.h - The CaptureTheFlag player.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef CAPTURETHEFLAGPLAYER_H_
#define CAPTURETHEFLAGPLAYER_H_

#include "ThreeFloats.h"
#include "Player.h"
#include "Star.h"

class GameCounter;
class Flag;

///	The CaptureTheFlag player.
class CaptureTheFlagPlayer : public Player
{
  public:
	///	Constructor.
	CaptureTheFlagPlayer(const TwoFloats& pos, const ThreeFloats& col);
	///	Destructor.
	~CaptureTheFlagPlayer();

	///	Moves the player.
	void update(const TwoFloats& drawSize);
	///	Draws the player.
	void draw(shared_ptr<Drawer>& d);

	///	Called when a key is pressed down.
	void keyDown(const std::wstring& action);
	///	Called when a key is pressed up.
	void keyUp(const std::wstring& action);
	///	Called when a joystick event is received.
	void joystick(const std::wstring& action, float val);
	
	///	Updates the collidable's position.
	void setPosition(const TwoFloats& pos);
	///	Returns the collidable's position.
	const TwoFloats& getPosition() const {return position;};

	///	Updates the collidable's direction.
	void setDirection(const TwoFloats& dir);
	///	Returns the collidable's direction.
	const TwoFloats& getDirection() const {return realDirection;};

	///	Returns the collidable's radius.
	float getRadius() const {return 20.0f;};

	///	Returns the collidable's name.
	const std::wstring& getName() const {return name;};

	///	Called to test/react to collisions with other objects.
	void collide(const shared_ptr<Collidable>& other);

	///	Sets the bat's colour.
	void setColour(const ThreeFloats& col);
	///	Returns the player's colour.
	const ThreeFloats& getColour() const {return colour;};

	///	Sets the player's flag.
	void setFlag(shared_ptr<Flag>& f);
	///	Returns true if the player is carrying a flag.
	bool getFlag() const {return (flag != 0);};

	///	Returns true if the player is now dead.
	bool getDead() const {return dead;};
  private:
	///	The position of the CaptureTheFlag player's head.
	TwoFloats position;
	///	The CaptureTheFlag player's name.
	std::wstring name;
	///	The CaptureTheFlag player's colour.
	ThreeFloats colour;

	///	> 0 if the player's stunned.
	int stunned;
	///	The star that's displayed if the player's stunned.
	Star star;

	///	The CaptureTheFlag player's current direction.
	TwoFloats direction;
	///	The CaptureTheFlag player's current direction.
	TwoFloats realDirection;
	///	The CaptureTheFlag player's current angle.
	float angle;
	///	Animates the player's arms.
	float armPos;

	///	The flag we're carrying.
	shared_ptr<Collidable> flag;

	///	Used to move the CaptureTheFlag player.
	bool upIsDown;
	///	Used to move the CaptureTheFlag player.
	bool downIsDown;
	///	Used to move the CaptureTheFlag player.
	bool leftIsDown;
	///	Used to move the CaptureTheFlag player.
	bool rightIsDown;

	///	True if the player's dead.
	bool dead;
};

#endif
