//	DeadPlayer.cpp - Gravestone for player killed by zombies.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "DeadPlayer.h"

//------------------------------------------------------------------------------
DeadPlayer::DeadPlayer(const TwoFloats& pos, const ThreeFloats& col):
Player(pos),
position(pos),
name(L"DeadPlayer"),
colour(col)
{

}

//------------------------------------------------------------------------------
DeadPlayer::~DeadPlayer()
{

}

//------------------------------------------------------------------------------
void DeadPlayer::draw(shared_ptr<Drawer>& d)
{
	d->drawImage(L"Gravestone", position-24.0f, 1.0f, colour);
}

//------------------------------------------------------------------------------
void DeadPlayer::collide(const shared_ptr<Collidable>& other)
{
	const float radius(24.0f);
	TwoFloats otherPos(other->getPosition());
	const float otherRad(other->getRadius());

	if(otherPos.getDistance(position) < (otherRad+radius))
	{
		float offset;
		TwoFloats diff(position - otherPos);
		float dist = diff.getMagnitude();
		float rad = getRadius() + other->getRadius();

		diff = diff.normal();
		offset = (rad - dist);
		otherPos -= diff * offset;

		other->setPosition(otherPos);
	}
}
