//	Flag.h - Flag for the capture the flag game.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef FLAG_H_
#define FLAG_H_

#include "ThreeFloats.h"
#include "NPC.h"

class Drawer;

///	Flag for the capture the flag game.
class Flag : public NPC
{
  public:
	///	Constructor.
	Flag(const TwoFloats& pos, const ThreeFloats& col);
	///	Destructor.
	~Flag();

	///	Moves the NPC.
	void update(const TwoFloats& drawSize);
	///	Draws the NPC.
	void draw(shared_ptr<Drawer>& d);

	///	Resets the flag's position.
	void reset();
	///	Tells the flag to fly off in a random direction.
	void flyOff();
	
	///	Kills the NPC.
	void setDead();
	///	Returns true if the NPC can be deleted.
	bool isDead() const {return dead;};

	///	Updates the collidable's position.
	void setPosition(const TwoFloats& pos);
	///	Returns the collidable's position.
	const TwoFloats& getPosition() const {return position;};

	///	Updates the collidable's direction.
	void setDirection(const TwoFloats& dir) {};
	///	Returns the collidable's direction.
	const TwoFloats& getDirection() const {return direction;};

	///	Returns the collidable's radius.
	float getRadius() const {return 16.0f;};

	///	Returns the collidable's name.
	const std::wstring& getName() const {return name;};

	///	Called to test/react to collisions with other objects.
	void collide(const shared_ptr<Collidable>& other) {};

	///	Sets the Flag's colour.
	void setColour(const ThreeFloats& col);
	///	Returns the Flag's colour.
	const ThreeFloats& getColour() const {return colour;};
  private:
	///	The Flag's position.
	TwoFloats position;
	///	The Flag's direction.
	TwoFloats direction;
	///	The Flag's name.
	std::wstring name;
	///	The Flag's colour.
	ThreeFloats colour;

	///	The flag's starting position.
	TwoFloats startPosition;

	///	Used to fling the flag off in a random direction.
	float fling;

	///	True if the Flag's now dead.
	bool dead;
};

#endif
