//	NPC.h - Base class for the various NPC types.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef NPC_H_
#define NPC_H_

#include "Collidable.h"

class Drawer;

///	Base class for the various NPC types.
class NPC : public Collidable
{
  public:
	///	Constructor.
	NPC() {};
	///	Destructor.
	virtual ~NPC() {};

	///	Moves the NPC.
	virtual void update(const TwoFloats& drawSize) = 0;
	///	Draws the NPC.
	virtual void draw(shared_ptr<Drawer>& d) = 0;

	///	Kills the NPC.
	virtual void setDead() = 0;
	///	Returns true if the NPC can be deleted.
	virtual bool isDead() const = 0;

	///	Returns the NPC's colour.
	virtual const ThreeFloats& getColour() const = 0;
};

#endif
