//	Player.h - Base class for the various player types.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef PLAYER_H_
#define PLAYER_H_

#include "Collidable.h"

class Drawer;

///	Base class for the various player types.
class Player : public Collidable
{
  public:
	///	Constructor.
	Player(const TwoFloats& pos) {};
	///	Destructor.
	virtual ~Player() {};

	///	Moves the player.
	virtual void update(const TwoFloats& drawSize) = 0;
	///	Draws the player.
	virtual void draw(shared_ptr<Drawer>& d) = 0;

	///	Called when a key is pressed down.
	virtual void keyDown(const std::wstring& action) = 0;
	///	Called when a key is pressed up.
	virtual void keyUp(const std::wstring& action) = 0;
	///	Called when a joystick event is received.
	virtual void joystick(const std::wstring& action, float val) = 0;

	///	Sets the player's colour.
	virtual void setColour(const ThreeFloats& col) = 0;
	///	Returns the player's colour.
	virtual const ThreeFloats& getColour() const = 0;

	///	Returns true if the player is carrying a flag.
	virtual bool getFlag() const {return false;};
};

#endif
