//	PongPlayer.cpp - Basic pong bat.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "PongPlayer.h"

//------------------------------------------------------------------------------
PongPlayer::PongPlayer(const TwoFloats& pos):
Player(pos),
position(pos),
name(L"PongPlayer"),
colour(1.0f),
upIsDown(false),
downIsDown(false)
{

}

//------------------------------------------------------------------------------
PongPlayer::~PongPlayer()
{

}

//------------------------------------------------------------------------------
void PongPlayer::update(const TwoFloats& drawSize)
{
	const float speed(12.0f);

	if(direction.y != 0.0f)
	{
		position.y += direction.y * speed;
		if(position.y > (drawSize.y-32.0f-64.0f))
			position.y = drawSize.y-32.0f-64.0f;
		else if(position.y < (32.0f+64.0f))
			position.y = 32.0f + 64.0f;
	}
}

//------------------------------------------------------------------------------
void PongPlayer::draw(shared_ptr<Drawer>& d)
{
	d->fillRect(TwoFloats(position.x-16, position.y-64),
				TwoFloats(32.0f, 128.0f),
				colour);
}

//------------------------------------------------------------------------------
void PongPlayer::keyDown(const std::wstring& action)
{
	if(action == L"Up")
	{
		upIsDown = true;
		if(!downIsDown)
			direction.y = -1.0f;
		else
			direction.y = 0.0f;
	}
	else if(action == L"Down")
	{
		downIsDown = true;
		if(!upIsDown)
			direction.y = 1.0f;
		else
			direction.y = 0.0f;
	}
}

//------------------------------------------------------------------------------
void PongPlayer::keyUp(const std::wstring& action)
{
	if(action == L"Up")
	{
		upIsDown = false;
		if(downIsDown)
			direction.y = 1.0f;
		else
			direction.y = 0.0f;
	}
	else if(action == L"Down")
	{
		downIsDown = false;
		if(upIsDown)
			direction.y = -1.0f;
		else
			direction.y = 0.0f;
	}
}

//------------------------------------------------------------------------------
void PongPlayer::joystick(const std::wstring& action, float val)
{
	if((action == L"Up") || (action == L"Down"))
	{
		direction.y = val;
		if(fabsf(direction.y) < 0.15f)
			direction.y = 0.0f;
	}
}

//------------------------------------------------------------------------------
void PongPlayer::setPosition(const TwoFloats& pos)
{
	position.y = pos.y;
}

//------------------------------------------------------------------------------
void PongPlayer::setDirection(const TwoFloats& dir)
{
	direction.y = dir.y;
}

//------------------------------------------------------------------------------
void PongPlayer::collide(const shared_ptr<Collidable>& other)
{
	if(other->getName() == L"Ball")
	{
		TwoFloats ballDir(other->getDirection());
		const TwoFloats& ballPos(other->getPosition());
		const TwoFloats size(32.0f+16.0f, 128.0f+16.0f);
		const TwoFloats topLeft(position.x-16.0f-16.0f, position.y-64.0f-16.0f);
		const bool left(position.x < 640.0f);

		if(ballPos.isWithin(topLeft, size))
		{
			if(left && (ballDir.x < 0.0f))
				ballDir.x = -ballDir.x;
			else if(!left && (ballDir.x > 0.0f))
				ballDir.x = -ballDir.x;

			ballDir.y += direction.y;
			ballDir = ballDir.normal();
			other->setDirection(ballDir);
		}
	}
}

//------------------------------------------------------------------------------
void PongPlayer::setColour(const ThreeFloats& col)
{
	colour = col;
}
