//	TitleScreen.cpp - The title screen state.
//  ----------------------------------------------------------------------------
//	This file is part of 'NiallsAVLib', base code for any kind of audiovisual
//	apps.
//	Copyright (C) 2012  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#include "drawing/Drawer.h"
#include "TitleScreen.h"

//------------------------------------------------------------------------------
GameStateCreator<TitleScreen> TitleScreen::creator;
bool TitleScreen::firstGo(true);

//------------------------------------------------------------------------------
TitleScreen::TitleScreen(Application& app, SounderPtr& sound):
GameState(app, sound),
selectedEntry(0),
noiseSeedInc(0.0f),
noiseCount(2),
joystickY(0.0f),
joystickCount(0)
{

}

//------------------------------------------------------------------------------
TitleScreen::~TitleScreen()
{

}

//------------------------------------------------------------------------------
void TitleScreen::update()
{
	if(joystickY != 0.0f)
	{
		--joystickCount;
		if(joystickCount <= 0)
		{
			joystickCount = 30;

			if(joystickY < 0.0f)
			{
				--selectedEntry;
				if(selectedEntry < 0)
					selectedEntry = 1;
			}
			else
			{
				++selectedEntry;
				selectedEntry %= 2;
			}
		}
	}
}

//------------------------------------------------------------------------------
void TitleScreen::draw(DrawerPtr& d, float timestepInterp)
{
	const TwoFloats& drawSize(d->getDrawingAreaSize());
	if(firstGo)
	{
		d->useShader(L"AddNoise");
		d->registerShaderParam(L"noiseSeedInc");
		d->registerShaderParam(L"brightness");
		d->registerShaderParam(L"saturation");
		d->registerShaderParam(L"contrast");
		d->useShader(L"");

		firstGo = false;
	}

	d->startFrameBufferDrawing();

	//Draw background.
	d->fillRect(0.0f, drawSize, 0.0f);

	d->fillRect(0.0f, TwoFloats(drawSize.x, 32.0f), 1.0f);
	d->fillRect(TwoFloats(0.0f, drawSize.y-32.0f),
				TwoFloats(drawSize.x, 32.0f),
				1.0f);

	//Title text.
	d->drawText(L"Minimal 2 Player Game",
				L"ScoreFont",
				titleText,
				TwoFloats(0.0f, 192.0f),
				drawSize.x,
				TextLayout::Centre,
				1.0f,
				1.0f);

	switch(selectedEntry)
	{
		case 0: //Play game.
			d->drawText(L"Play Game",
						L"ScoreFont",
						playText[0],
						TwoFloats(0.0f, (drawSize.y*0.5f)+64.0f),
						drawSize.x,
						TextLayout::Centre,
						1.0f,
						1.0f);
			d->drawText(L"Quit",
						L"TickerFont",
						quitText[0],
						TwoFloats(0.0f, (drawSize.y*0.5f)+192.0f),
						drawSize.x,
						TextLayout::Centre,
						1.0f,
						1.0f);
			break;
		case 1: //Quit.
			d->drawText(L"Play Game",
						L"TickerFont",
						playText[1],
						TwoFloats(0.0f, (drawSize.y*0.5f)+32.0f),
						drawSize.x,
						TextLayout::Centre,
						1.0f,
						1.0f);
			d->drawText(L"Quit",
						L"ScoreFont",
						quitText[1],
						TwoFloats(0.0f, (drawSize.y*0.5f)+192.0f+32.0f),
						drawSize.x,
						TextLayout::Centre,
						1.0f,
						1.0f);
			break;
	}

	d->endFrameBufferDrawing();

	d->useShader(L"AddNoise");
	{
		d->setShaderParam(L"noiseSeedInc", noiseSeedInc);

		d->drawImage(d->getFrameBufferImage(), 0.0f, 1.0f);
	}
	d->useShader(L"");

	--noiseCount;
	if(!noiseCount)
	{
		noiseCount = 8;

		noiseSeedInc += 0.01f;
		if(noiseSeedInc > 1.0f)
			noiseSeedInc -= 1.0f;
	}
}

//------------------------------------------------------------------------------
void TitleScreen::keyDown(const std::wstring& action,
						  const std::wstring& keyPressed,
						  int keyModifier)
{
	if(action == L"Escape")
		quit();
	else if((action == L"P1Up") || (action == L"P2Up"))
	{
		--selectedEntry;
		if(selectedEntry < 0)
			selectedEntry = 1;
	}
	else if((action == L"P1Down") || (action == L"P2Down"))
	{
		++selectedEntry;
		selectedEntry %= 2;
	}
	else if((action == L"P1Fire") || (action == L"P2Fire"))
	{
		switch(selectedEntry)
		{
			case 0: //Play.
				nextState(L"GamePlayState");
				break;
			case 1:
				quit();
				break;
		}
	}
}

//------------------------------------------------------------------------------
void TitleScreen::keyUp(const std::wstring& action,
						  const std::wstring& keyPressed,
						  int keyModifier)
{

}

//------------------------------------------------------------------------------
void TitleScreen::joyMove(const std::wstring& action,
						  float value,
						  int joystick,
						  int axis)
{
	if((action == L"P1Up") || (action == L"P1Down"))
	{
		if(fabsf(value) > 0.15f)
			joystickY = value;
		else
		{
			joystickY = 0.0f;
			joystickCount = 0;
		}
	}
}
