//	Zombie.h - A zombie.
//  ----------------------------------------------------------------------------
//	This file is part of 'Minimal2PGame', a Ludum Dare entry.
//	Copyright (C) 2013  Niall Moody
//	
//	This program is free software: you can redistribute it and/or modify
//	it under the terms of the GNU General Public License as published by
//	the Free Software Foundation, either version 3 of the License, or
//	(at your option) any later version.
//
//	This program is distributed in the hope that it will be useful,
//	but WITHOUT ANY WARRANTY; without even the implied warranty of
//	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//	GNU General Public License for more details.
//
//	You should have received a copy of the GNU General Public License
//	along with this program.  If not, see <http://www.gnu.org/licenses/>.
//	----------------------------------------------------------------------------

#ifndef ZOMBIE_H_
#define ZOMBIE_H_

#include "ThreeFloats.h"
#include "NPC.h"

class GameCounter;
class Drawer;
class Player;

///	A zombie.
class Zombie : public NPC
{
  public:
	///	Constructor.
	Zombie(const TwoFloats& pos,
		   const ThreeFloats& col,
		   shared_ptr<Player>& p,
		   GameCounter& counter);
	///	Destructor.
	~Zombie();

	///	Moves the NPC.
	void update(const TwoFloats& drawSize);
	///	Draws the NPC.
	void draw(shared_ptr<Drawer>& d);
	
	///	Kills the NPC.
	void setDead();
	///	Returns true if the NPC can be deleted.
	bool isDead() const {return dead;};

	///	Updates the collidable's position.
	void setPosition(const TwoFloats& pos);
	///	Returns the collidable's position.
	const TwoFloats& getPosition() const {return position;};

	///	Updates the collidable's direction.
	void setDirection(const TwoFloats& dir) {};
	///	Returns the collidable's direction.
	const TwoFloats& getDirection() const {return direction;};

	///	Returns the collidable's radius.
	float getRadius() const {return 24.0f;};

	///	Returns the collidable's name.
	const std::wstring& getName() const {return name;};

	///	Called to test/react to collisions with other objects.
	void collide(const shared_ptr<Collidable>& other);

	///	Sets the Zombie's colour.
	void setColour(const ThreeFloats& col);
	///	Returns the Zombie's colour.
	const ThreeFloats& getColour() const {return origColour;};
  private:
	///	The Zombie's position.
	TwoFloats position;
	///	The Zombie's direction.
	TwoFloats direction;
	///	The Zombie's name.
	std::wstring name;
	///	The Zombie's colour.
	ThreeFloats colour;

	///	The zombie's original colour.
	ThreeFloats origColour;
	///	The zombie's actual direction.
	TwoFloats realDir;
	///	The zombie's speed.
	float speed;

	///	The player the zombie is aiming at.
	shared_ptr<Player> player;

	///	True if the Zombie's now dead.
	bool dead;

	///	Our copy of the game counter.
	GameCounter& gameCounter;
};

#endif
